@@ -1,4 +1,4 @@
-/* Atomix -- a little mind game about atoms and molecules.
+/* Atomix -- a little puzzle game about atoms and molecules.
  * Copyright (C) 1999 Jens Finke
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,42 +19,43 @@
 #ifndef _ATOMIX_BOARD_H_
 #define _ATOMIX_BOARD_H_
 
-#include "level.h"
+#include "theme.h"
+#include "playfield.h"
+#include "goal.h"
 
 enum
 {
-	BOARD_MSG_NONE,
-	BOARD_MSG_GAME_PAUSED,
-	BOARD_MSG_NEW_GAME,
-	BOARD_MSG_GAME_OVER
+  BOARD_MSG_NONE,
+  BOARD_MSG_GAME_PAUSED,
+  BOARD_MSG_NEW_GAME,
+  BOARD_MSG_GAME_OVER
 };
 
-void board_init(void);
+void board_init (Theme * theme, GnomeCanvas * canvas);
 
-void board_init_level(Level *l);
+void board_init_level (PlayField * env, PlayField * sce, Goal * goal);
 
-void board_destroy(void);
+void board_destroy (void);
 
-void board_clear(void);
+void board_clear (void);
 
-void board_print(void);
+void board_print (void);
 
-void board_hide(void);
+void board_hide (void);
 
-void board_show(void);
+void board_show (void);
 
-void board_show_normal_cursor(void);
+void board_show_normal_cursor (void);
 
-gboolean board_undo_move(void);
+gboolean board_undo_move (void);
 
-void  board_view_message(gint msg_id);
+void board_view_message (gint msg_id);
 
-void  board_hide_message(gint msg_id);
+void board_hide_message (gint msg_id);
 
-void board_handle_key_event(GdkEventKey *event);
+void board_show_logo (gboolean visible);
 
-void board_set_mouse_control(void);
-
-void board_set_keyboard_control(void);
+void board_handle_key_event (GObject * canvas, GdkEventKey * event,
+			     gpointer data);
 
 #endif /* _ATOMIX_BOARD_H_ */
