@@ -1,4 +1,4 @@
-/* Atomix -- a little mind game about atoms and molecules.
+/* Atomix -- a little puzzle game about atoms and molecules.
  * Copyright (C) 1999 Jens Finke
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,26 +21,23 @@
 
 #include <gnome.h>
 
-typedef struct _UndoMove  UndoMove;
-
-struct _UndoMove
+typedef struct
 {
-	GnomeCanvasItem *item;
-	gint src_row;
-	gint src_col;
-	gint dest_row;
-	gint dest_col;
-};
+  GnomeCanvasItem *item;
+  gint src_row;
+  gint src_col;
+  gint dest_row;
+  gint dest_col;
+} UndoMove;
 
-UndoMove* undo_create_move(GnomeCanvasItem *item, gint src_row, gint src_col,
-			   gint dest_row, gint dest_col);
+gboolean undo_exists (void);
 
-void  undo_init(void);
+void undo_push_move (GnomeCanvasItem * item,
+		     gint src_row, gint src_col,
+		     gint dest_row, gint dest_col);
 
-void undo_add_move(UndoMove *move);
+UndoMove *undo_pop_move (void);
 
-UndoMove* undo_get_last_move(void);
-
-void undo_free_all_moves(void);
+void undo_clear (void);
 
 #endif /* _ATOMIX_UNDO_H_ */
